#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework
version: 0.8.1.1
id: test-framework-0.8.1.1-a9fe3ef1175e4639905fc641f904c6e2
key: testf_B1MVPJUrcmB7HNAGf4Uv93
license: BSD3
maintainer: Libraries List <libraries@haskell.org>
homepage: https://batterseapower.github.io/test-framework/
synopsis: Framework for running and organising tests, with HUnit and QuickCheck support
description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.Console Test.Framework.Runners.Options
    Test.Framework.Runners.TestPattern Test.Framework.Runners.API
    Test.Framework.Seed
hidden-modules: Test.Framework.Core Test.Framework.Improving
                Test.Framework.Runners.Console.Colors
                Test.Framework.Runners.Console.ProgressBar
                Test.Framework.Runners.Console.Run
                Test.Framework.Runners.Console.Statistics
                Test.Framework.Runners.Console.Table
                Test.Framework.Runners.Console.Utilities
                Test.Framework.Runners.Core Test.Framework.Runners.Processors
                Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
                Test.Framework.Runners.TimedConsumption
                Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
                Test.Framework.Utilities
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/test-framework-0.8.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/test-framework-0.8.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/test-framework-0.8.1.1
hs-libraries: HStest-framework-0.8.1.1-B1MVPJUrcmB7HNAGf4Uv93
depends:
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    ansi-wl-pprint-0.6.7.3-28ee0530b985e8f17809a30013a735ed
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    hostname-1.0-124b2f31791690b14b909fa68059a8bc
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    regex-posix-0.95.2-7db894a782ed7a4a4d46c02c0db4ce39
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    xml-1.3.14-6291d85df68e094bfca87f33fea8b24c
haddock-interfaces: /usr/share/doc/haskell-test-framework/html/test-framework.haddock
haddock-html: /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
